pub struct Agent {
pub config: AgentConfig,
pub cookies: Vec<Cookie>,
}Fields
config: AgentConfigImplementations
Sourceimpl Agent
impl Agent
pub fn new(config: AgentConfig, cookies: Vec<Cookie>) -> Self
pub fn command(&self) -> &str
Sourcepub async fn check_limit(&self) -> Result<AgentLimit, Box<dyn Error>>
pub async fn check_limit(&self) -> Result<AgentLimit, Box<dyn Error>>
Errors
Returns an error if fetching usage from the provider API fails or the domain is unknown.
Sourcepub async fn fetch_status(&self) -> Result<AgentStatus, Box<dyn Error>>
pub async fn fetch_status(&self) -> Result<AgentStatus, Box<dyn Error>>
Errors
Returns an error if fetching usage from the provider API fails or the domain is unknown.