pub struct ClaudeClient;Implementations
Sourceimpl ClaudeClient
impl ClaudeClient
Sourcepub async fn fetch_usage_with_header(
cookie_header: &str,
org_id: &str,
) -> Result<UsageResponse>
pub async fn fetch_usage_with_header( cookie_header: &str, org_id: &str, ) -> Result<UsageResponse>
Fetch usage using a pre-built cookie header string and org ID.
Errors
Returns an error if the API request fails or the response cannot be parsed.
Sourcepub async fn fetch_usage(cookies: &[Cookie]) -> Result<UsageResponse>
pub async fn fetch_usage(cookies: &[Cookie]) -> Result<UsageResponse>
Errors
Returns an error if the org ID cookie is missing, the API request fails, or the response cannot be parsed.