run_codexbar_usage

Function run_codexbar_usage 

pub async fn run_codexbar_usage(
    provider: &str,
    opts: &RunCodexBarUsageOptions,
) -> Result<CodexBarUsageResponse, CodexBarError>
Run codexbar usage --format json --provider <provider> and return the entry matching provider.

Errors

Returns CodexBarError when the binary is missing, the process fails or times out, the output is not valid JSON, or no entry matches provider.