pub struct Agent {
pub config: AgentConfig,
pub cookies: Vec<Cookie>,
}Fields
config: AgentConfigImplementations
Sourceimpl Agent
impl Agent
pub fn new(config: AgentConfig, cookies: Vec<Cookie>) -> Self
pub fn command(&self) -> &str
pub fn args(&self) -> &[String]
Sourcepub async fn check_limit(&self) -> Result<AgentLimit, Box<dyn Error>>
pub async fn check_limit(&self) -> Result<AgentLimit, Box<dyn Error>>
Errors
Returns an error if fetching usage from the provider API fails or the domain is unknown.
Sourcepub async fn fetch_status(&self) -> Result<AgentStatus, Box<dyn Error>>
pub async fn fetch_status(&self) -> Result<AgentStatus, Box<dyn Error>>
Errors
Returns an error if fetching usage from the provider API fails or the domain is unknown.
Sourcepub fn execute(
&self,
resolved_args: &[String],
extra_args: &[String],
) -> Result<ExitStatus>
pub fn execute( &self, resolved_args: &[String], extra_args: &[String], ) -> Result<ExitStatus>
Errors
Returns an error if spawning or waiting on the child process fails.
pub fn has_model(&self, model_key: &str) -> bool
pub fn resolved_args(&self, model: Option<&str>) -> Vec<String>
pub fn mapped_args(&self, args: &[String]) -> Vec<String>