pub async fn serve(
settings: Settings,
config_path: Option<PathBuf>,
) -> Result<(), Box<dyn Error>>Expand description
Start the config editor web server, open the browser, and block until Ctrl+C.
Errors
Returns an error if the TCP listener cannot be bound or the server fails.